@@ -340,6 +340,30 @@ public:
         return best_idx(tol_vector);
     }
 
+    /// Index of the worst individual
+    /**
+     * If the problem is single-objective and unconstrained, the worst
+     * is simply the individual with the largest fitness. If the problem
+     * is, instead, single objective, but with constraints, the worst individual
+     * will be defined using the criteria specified in pagmo::sort_population_con().
+     * If the problem is multi-objective one single worst is not defined. In
+     * this case the user can still obtain a strict ordering of the population
+     * individuals by calling the pagmo::sort_population_mo() function.
+     *
+     * The pagmo::population::get_c_tol() tolerances are accounted by default.
+     * If different tolerances are required the other overloads can be used.
+     *
+     * @returns the index of the worst individual.
+     *
+     * @throws std::invalid_argument if the problem is multiobjective and thus
+     * a worst individual is not well defined, or if the population is empty.
+     * @throws unspecified any exception thrown by pagmo::sort_population_con().
+     */
+     size_type worst_idx() const
+     {
+         return worst_idx(get_problem().get_c_tol());
+     }
+
     /// Index of the worst individual (accounting for a vector tolerance)
     /**
      * If the problem is single-objective and unconstrained, the worst
@@ -383,7 +407,7 @@ public:
      *
      * @return index of the worst individual.
      */
-    size_type worst_idx(double tol = 0.) const
+    size_type worst_idx(double tol) const
     {
         vector_double tol_vector(m_prob.get_nf() - 1u, tol);
         return worst_idx(tol_vector);
@@ -410,6 +434,10 @@ public:
             pagmo_throw(std::invalid_argument,
                         "The Champion of a population can only be extracted in single objective problems");
         }
+        if (m_prob.is_stochastic()) {
+            pagmo_throw(std::invalid_argument,
+                        "The Champion of a population can only be extracted for non stochastic problems");
+        }
         return m_champion_x;
     }
 
@@ -434,6 +462,10 @@ public:
             pagmo_throw(std::invalid_argument,
                         "The Champion of a population can only be extracted in single objective problems");
         }
+        if (m_prob.is_stochastic()) {
+            pagmo_throw(std::invalid_argument,
+                        "The Champion of a population can only be extracted for non stochastic problems");
+        }
         return m_champion_f;
     }
 
